@@ -6,6 +6,7 @@ urllib3.disable_warnings()
 import json
 import webbrowser
 import sys
+import re
 
 """
 Veeam Easy Connect
@@ -217,8 +218,9 @@ class VeeamEasyConnect:
                 #":11005/api/v1/token"
                 # check if oauth is in the url_end as that means we need to go back 
                 # two splits unlike the others that need 1
-                split_qty = -2 if "oauth" in self.url_end else -1
-                url_middle = "/".join(self.url_end.split("/")[:split_qty]) + "/"
+                # split_qty = -2 if "oauth" in self.url_end else -1
+                url_middle = re.split('oauth|v[0-9]', self.url_end)[0]
+                # url_middle = "/".join(self.url_end.split("/")[:split_qty]) + "/"
                 # the beginning / has been removed from the request variable
                 # But the api_version doesn't have the trailing / so needs to be added
                 return f"https://{self.address}{url_middle}{self.api_version}/{request}"
@@ -260,7 +262,10 @@ class VeeamEasyConnect:
 
     def get_api_version(self) -> None:
         if not self.basic:
-            return self.oauth_headers['x-api-version']
+            if len(self.url_end) > 0:
+                return self.api_version
+            else:
+                raise Exception("The API type needs to be set")
         else:
             return "latest"
 
